import * as i0 from '@angular/core';
import { EventEmitter, Injectable, Component, ViewChild, Input, Output } from '@angular/core';
import * as i4 from '@po-ui/ng-components';
import { PoModule } from '@po-ui/ng-components';
import * as i3 from 'angularx-qrcode';
import { QRCodeModule } from 'angularx-qrcode';
import * as i2 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as signalR from '@microsoft/signalr';
import { lastValueFrom } from 'rxjs';
import * as i1 from '@angular/common/http';

class SignalRService {
    constructor(http) {
        this.http = http;
        this.messageReceived = new EventEmitter();
        this.host = '';
    }
    initializeConnection() {
        this.hubConnection = new signalR.HubConnectionBuilder()
            .withUrl(`${this.host}api`)
            .build();
    }
    async startConnection() {
        if (this.hubConnection?.state === signalR.HubConnectionState.Connected) {
            await this.hubConnection.stop();
        }
        try {
            await this.hubConnection?.start();
        }
        catch (err) {
            throw err;
        }
    }
    async negotiate() {
        try {
            const response = await lastValueFrom(this.http.post(`${this.host}api/negotiate`, {
                headers: {
                    'Content-Type': 'application/json',
                    'x-functions-key': ''
                }
            }));
            return response;
        }
        catch (err) {
            throw err;
        }
    }
    async joinGroup(groupNameID) {
        try {
            const response = await lastValueFrom(this.http.post(`${this.host}api/AddUser`, null, {
                headers: {
                    'Content-Type': 'application/json',
                    'GroupId': groupNameID,
                    'IDTOTVS': groupNameID,
                    'x-functions-key': ''
                }
            }));
            return response;
        }
        catch (err) {
            throw err;
        }
    }
    async removeFromGroup(groupNameID) {
        try {
            const response = await lastValueFrom(this.http.post(`${this.host}api/RemoveFromGroup`, null, {
                headers: {
                    'Content-Type': 'application/json',
                    'GroupId': groupNameID,
                    'x-functions-key': ''
                }
            }));
            return response;
        }
        catch (err) {
            throw err;
        }
    }
    async sendMessageToGroup(groupNameID, message) {
        try {
            const response = await lastValueFrom(this.http.post(`${this.host}api/SendToGroup`, message, {
                headers: {
                    'Content-Type': 'application/json',
                    'GroupId': groupNameID,
                    'MessageIdUnique': groupNameID,
                    'x-functions-key': ''
                }
            }));
            return response;
        }
        catch (err) {
            throw err;
        }
    }
    listenForMessageUnique(nameMessage) {
        this.hubConnection?.on(nameMessage, (message) => {
            console.log('Mensagem message:', message);
            this.messageReceived.emit(message);
        });
    }
    stopMessages(messageIdUnique) {
        this.hubConnection?.off(messageIdUnique);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: SignalRService, deps: [{ token: i1.HttpClient }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: SignalRService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: SignalRService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: i1.HttpClient }] });

class TotvsVisionOCRComponent {
    toggleSidebar() {
        this.isCollapsed = !this.isCollapsed;
        if (this.sidebarBgColor !== 'transparent') {
            this.sidebarBgColorAux = this.sidebarBgColor;
        }
        this.sidebarBgColor = this.isCollapsed ? 'transparent' : this.sidebarBgColorAux;
    }
    constructor(signalRService) {
        this.signalRService = signalRService;
        this.listButtonsDocument = [];
        this.host = '';
        this.groupIdUnique = '';
        this.sidebarBgColor = 'transparent';
        this.informacaoEnviada = new EventEmitter();
        this.sidebarBgColorAux = 'transparent';
        this.documentos = [];
        this.isCollapsed = false;
        this.myAngularxQrCode = 'hello';
        this.myAngularxQrCode = 'Your QR code data string';
    }
    async ngOnDestroy() {
        await this.signalRService.removeFromGroup(this.groupIdUnique);
        this.signalRService.stopMessages(this.groupIdUnique);
    }
    ngOnInit() {
        this.initializeSignalRConnection();
        this.signalRService.messageReceived.subscribe((message) => {
            console.log('Received message:', message);
            this.informacaoEnviada.emit({
                menssagem: message,
                uniqueKey: Date.now()
            });
        });
    }
    async initializeSignalRConnection() {
        try {
            this.signalRService.host = this.host;
            this.signalRService.initializeConnection();
            await this.signalRService.startConnection();
            await this.signalRService.joinGroup(this.groupIdUnique);
            this.signalRService.listenForMessageUnique(this.groupIdUnique);
        }
        catch (error) {
            console.error('Initialization failed:', error);
        }
    }
    openQrCodeModal() {
        this.qrCodeModal?.open();
    }
    openListModal() {
        this.listModal?.open();
    }
    triggerFileInput(index) {
        document.getElementById('fileInput' + index)?.click();
    }
    onFileSelected(event, index) {
        const file = event.target.files[0];
        if (file) {
            const reader = new FileReader();
            reader.onload = () => {
                const base64Image = reader.result.split(',')[1];
                const documento = {
                    nameDocument: file.name,
                    base64Image: base64Image,
                    imageIdentifier: `img-${index}`
                };
                this.documentos[index] = documento;
            };
            reader.readAsDataURL(file);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: TotvsVisionOCRComponent, deps: [{ token: SignalRService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "17.3.12", type: TotvsVisionOCRComponent, isStandalone: true, selector: "totvs-vision-ocr", inputs: { listButtonsDocument: "listButtonsDocument", host: "host", groupIdUnique: "groupIdUnique", sidebarBgColor: "sidebarBgColor" }, outputs: { informacaoEnviada: "informacaoEnviada" }, viewQueries: [{ propertyName: "qrCodeModal", first: true, predicate: ["qrCodeModal"], descendants: true, static: true }, { propertyName: "listModal", first: true, predicate: ["listModal"], descendants: true, static: true }], ngImport: i0, template: "<po-modal #qrCodeModal p-title=\"QR Code\">\r\n  <div style=\"text-align: center;\">\r\n    <qrcode [qrdata]=\"myAngularxQrCode\" [width]=\"256\" [errorCorrectionLevel]=\"'M'\"></qrcode>\r\n  </div>\r\n</po-modal>\r\n\r\n<po-modal #listModal p-title=\"Imagens a serem carregadas localmente\">\r\n  <div class=\"button-container\">\r\n    @for (item of listButtonsDocument; track $index) {\r\n      <div class=\"button-wrapper\">\r\n        <input \r\n            type=\"file\" \r\n            class=\"file-input\" \r\n            (change)=\"onFileSelected($event, $index)\" \r\n            [id]=\"'fileInput' + $index\" \r\n            hidden>\r\n        <po-button \r\n          [p-label]=\"this.listButtonsDocument[$index].nameButton\"\r\n          (p-click)=\"triggerFileInput($index)\"\r\n          p-icon=\"{{ this.documentos[$index] ? 'ph ph-check' : '' }}\">\r\n        </po-button>\r\n      </div>\r\n    }\r\n  </div>\r\n</po-modal>\r\n\r\n<div class=\"sidebar\" [class.collapsed]=\"isCollapsed\" [ngStyle]=\"{'background-color': sidebarBgColor}\">\r\n  <div class=\"icons-wrapper\">\r\n    <button class=\"icon\" (click)=\"openQrCodeModal()\">\r\n      <i class=\"ph ph-qr-code\"></i>\r\n      <span class=\"tooltip\">QrCode</span>\r\n    </button>\r\n    <button class=\"icon\" (click)=\"openListModal()\">\r\n      <i class=\"ph ph-list-checks\"></i>\r\n      <span class=\"tooltip\">Lista</span>\r\n    </button>\r\n  </div>\r\n  <button class=\"icon toggle\" (click)=\"toggleSidebar()\" aria-label=\"Expandir/Colapsar Barra Lateral\">\r\n    <i class=\"ph\" [ngClass]=\"isCollapsed ? 'ph-caret-left' : 'ph-caret-right'\"></i>\r\n    <span class=\"tooltip\">Expandir</span>\r\n  </button>\r\n</div>", styles: [":host{display:flex}.sidebar{width:50px;background-color:transparent;height:100vh;padding:10px 0;border-left:1px solid #ddd;display:flex;flex-direction:column;align-items:center;transition:width .3s,border-left .3s;position:fixed;right:0;top:0;z-index:1000}.sidebar.collapsed{width:20px;border-left:none}.icon{width:24px;height:24px;background-size:cover;margin:20px 0;cursor:pointer;position:relative;border:none;background-color:transparent;background-image:none;display:flex;flex-direction:column;align-items:center;padding:0}.icon span.tooltip{visibility:hidden;width:max-content;background-color:#555;color:#fff;text-align:center;border-radius:6px;padding:5px 8px;position:absolute;z-index:1;top:50%;left:calc(-100% - 10px);transform:translateY(-50%);opacity:0;transition:opacity .3s}.icon span.tooltip:after{content:\"\";position:absolute;top:50%;right:-5px;transform:translateY(-50%);border-width:5px;border-style:solid;border-color:transparent transparent transparent #555}.icon:hover span.tooltip{visibility:visible;opacity:1}.toggle{position:absolute;bottom:10px;width:50px;border:none;background:none;cursor:pointer;padding:10px;display:flex;flex-direction:column;align-items:center}.toggle i{font-size:30px}.icons-wrapper{display:flex;flex-direction:column;align-items:center;transition:opacity .3s}.sidebar.collapsed .icons-wrapper{opacity:0}.sidebar.collapsed .toggle{opacity:1}.icon i{font-size:2rem;color:#333;display:block;width:3rem;height:3rem}.file-input{display:none}.button-container{display:flex;flex-wrap:wrap;gap:10px}.button-wrapper{display:flex;align-items:center;justify-content:center}@media (max-width: 768px){.sidebar{width:40px}.sidebar.collapsed{width:15px}.toggle{width:40px;font-size:26px}.icon{width:20px;height:20px;margin:15px 0}}@media (max-width: 480px){.sidebar{width:30px}.sidebar.collapsed{width:10px}.toggle{width:30px;font-size:22px}.icon{width:18px;height:18px;margin:10px 0}}@media (max-width: 320px){.sidebar{width:25px}.sidebar.collapsed{width:8px}.toggle{width:25px;font-size:18px}.icon{width:16px;height:16px;margin:8px 0}.icon span.tooltip{font-size:.8rem;padding:4px 6px}}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i2.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i2.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { kind: "ngmodule", type: QRCodeModule }, { kind: "component", type: i3.QRCodeComponent, selector: "qrcode", inputs: ["allowEmptyString", "colorDark", "colorLight", "cssClass", "elementType", "errorCorrectionLevel", "imageSrc", "imageHeight", "imageWidth", "margin", "qrdata", "scale", "version", "width", "alt", "ariaLabel", "title"], outputs: ["qrCodeURL"] }, { kind: "ngmodule", type: PoModule }, { kind: "component", type: i4.PoButtonComponent, selector: "po-button" }, { kind: "component", type: i4.PoModalComponent, selector: "po-modal" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: TotvsVisionOCRComponent, decorators: [{
            type: Component,
            args: [{ selector: 'totvs-vision-ocr', standalone: true, imports: [CommonModule, QRCodeModule, PoModule], template: "<po-modal #qrCodeModal p-title=\"QR Code\">\r\n  <div style=\"text-align: center;\">\r\n    <qrcode [qrdata]=\"myAngularxQrCode\" [width]=\"256\" [errorCorrectionLevel]=\"'M'\"></qrcode>\r\n  </div>\r\n</po-modal>\r\n\r\n<po-modal #listModal p-title=\"Imagens a serem carregadas localmente\">\r\n  <div class=\"button-container\">\r\n    @for (item of listButtonsDocument; track $index) {\r\n      <div class=\"button-wrapper\">\r\n        <input \r\n            type=\"file\" \r\n            class=\"file-input\" \r\n            (change)=\"onFileSelected($event, $index)\" \r\n            [id]=\"'fileInput' + $index\" \r\n            hidden>\r\n        <po-button \r\n          [p-label]=\"this.listButtonsDocument[$index].nameButton\"\r\n          (p-click)=\"triggerFileInput($index)\"\r\n          p-icon=\"{{ this.documentos[$index] ? 'ph ph-check' : '' }}\">\r\n        </po-button>\r\n      </div>\r\n    }\r\n  </div>\r\n</po-modal>\r\n\r\n<div class=\"sidebar\" [class.collapsed]=\"isCollapsed\" [ngStyle]=\"{'background-color': sidebarBgColor}\">\r\n  <div class=\"icons-wrapper\">\r\n    <button class=\"icon\" (click)=\"openQrCodeModal()\">\r\n      <i class=\"ph ph-qr-code\"></i>\r\n      <span class=\"tooltip\">QrCode</span>\r\n    </button>\r\n    <button class=\"icon\" (click)=\"openListModal()\">\r\n      <i class=\"ph ph-list-checks\"></i>\r\n      <span class=\"tooltip\">Lista</span>\r\n    </button>\r\n  </div>\r\n  <button class=\"icon toggle\" (click)=\"toggleSidebar()\" aria-label=\"Expandir/Colapsar Barra Lateral\">\r\n    <i class=\"ph\" [ngClass]=\"isCollapsed ? 'ph-caret-left' : 'ph-caret-right'\"></i>\r\n    <span class=\"tooltip\">Expandir</span>\r\n  </button>\r\n</div>", styles: [":host{display:flex}.sidebar{width:50px;background-color:transparent;height:100vh;padding:10px 0;border-left:1px solid #ddd;display:flex;flex-direction:column;align-items:center;transition:width .3s,border-left .3s;position:fixed;right:0;top:0;z-index:1000}.sidebar.collapsed{width:20px;border-left:none}.icon{width:24px;height:24px;background-size:cover;margin:20px 0;cursor:pointer;position:relative;border:none;background-color:transparent;background-image:none;display:flex;flex-direction:column;align-items:center;padding:0}.icon span.tooltip{visibility:hidden;width:max-content;background-color:#555;color:#fff;text-align:center;border-radius:6px;padding:5px 8px;position:absolute;z-index:1;top:50%;left:calc(-100% - 10px);transform:translateY(-50%);opacity:0;transition:opacity .3s}.icon span.tooltip:after{content:\"\";position:absolute;top:50%;right:-5px;transform:translateY(-50%);border-width:5px;border-style:solid;border-color:transparent transparent transparent #555}.icon:hover span.tooltip{visibility:visible;opacity:1}.toggle{position:absolute;bottom:10px;width:50px;border:none;background:none;cursor:pointer;padding:10px;display:flex;flex-direction:column;align-items:center}.toggle i{font-size:30px}.icons-wrapper{display:flex;flex-direction:column;align-items:center;transition:opacity .3s}.sidebar.collapsed .icons-wrapper{opacity:0}.sidebar.collapsed .toggle{opacity:1}.icon i{font-size:2rem;color:#333;display:block;width:3rem;height:3rem}.file-input{display:none}.button-container{display:flex;flex-wrap:wrap;gap:10px}.button-wrapper{display:flex;align-items:center;justify-content:center}@media (max-width: 768px){.sidebar{width:40px}.sidebar.collapsed{width:15px}.toggle{width:40px;font-size:26px}.icon{width:20px;height:20px;margin:15px 0}}@media (max-width: 480px){.sidebar{width:30px}.sidebar.collapsed{width:10px}.toggle{width:30px;font-size:22px}.icon{width:18px;height:18px;margin:10px 0}}@media (max-width: 320px){.sidebar{width:25px}.sidebar.collapsed{width:8px}.toggle{width:25px;font-size:18px}.icon{width:16px;height:16px;margin:8px 0}.icon span.tooltip{font-size:.8rem;padding:4px 6px}}\n"] }]
        }], ctorParameters: () => [{ type: SignalRService }], propDecorators: { qrCodeModal: [{
                type: ViewChild,
                args: ['qrCodeModal', { static: true }]
            }], listModal: [{
                type: ViewChild,
                args: ['listModal', { static: true }]
            }], listButtonsDocument: [{
                type: Input
            }], host: [{
                type: Input
            }], groupIdUnique: [{
                type: Input
            }], sidebarBgColor: [{
                type: Input
            }], informacaoEnviada: [{
                type: Output
            }] } });

/*
 * Public API Surface of totvs-vision-ocr
 */

/**
 * Generated bundle index. Do not edit.
 */

export { TotvsVisionOCRComponent };
//# sourceMappingURL=totvs-vision-ocr.mjs.map
